Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWillian Padovani Germano <wpgermano@gmail.com>2003-06-28 11:38:21 +0400
committerWillian Padovani Germano <wpgermano@gmail.com>2003-06-28 11:38:21 +0400
commiteaf1cdd3836aa425e3dc6f1a11d4556bd7e3e876 (patch)
treefe8e701c3e3daa38749b78238858edbbbfea1f91 /source/blender/python/api2_2x/Image.h
parent569a32a2ea3a1992eaeaa5dc0256c48e8a053fbd (diff)
- More renaming all around to follow our conventions
- Implemented partially Blender.Sys - Worked on issues related to sys, path - Took away most "debug" printfs
Diffstat (limited to 'source/blender/python/api2_2x/Image.h')
-rw-r--r--source/blender/python/api2_2x/Image.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/blender/python/api2_2x/Image.h b/source/blender/python/api2_2x/Image.h
index 08104875f7a..163eba90eb1 100644
--- a/source/blender/python/api2_2x/Image.h
+++ b/source/blender/python/api2_2x/Image.h
@@ -37,17 +37,17 @@
/*****************************************************************************/
/* Python C_Image structure definition */
/*****************************************************************************/
typedef struct {
PyObject_HEAD
Image *image;
-} C_Image;
+} BPy_Image;
extern PyTypeObject Image_Type; /* The Image PyType Object */
-#define C_Image_Check(v) ((v)->ob_type == &Image_Type) /* for type checking */
+#define BPy_Image_Check(v) ((v)->ob_type == &Image_Type)/*for type checking*/
/*****************************************************************************/
/* Module Blender.Image - public functions */
@@ -37,17 +37,17 @@
/*****************************************************************************/
-/* Python C_Image structure definition */
+/* Python BPy_Image structure definition */
/*****************************************************************************/
typedef struct {